@@ -2,7 +2,7 @@
 
 # geoarray, A fast Python interface for image geodata - either on disk or in memory.
 #
-# Copyright (C) 2017-2021
+# Copyright (C) 2017-2023
 # - Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
 # - Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences Potsdam,
 #   Germany (https://www.gfz-potsdam.de/)
@@ -365,12 +365,18 @@ class GeoArray(object):
         """Return 'True' if the image has a valid geoinformation with map instead of image coordinates."""
         return all([self.gt, list(self.gt) != [0, 1, 0, 0, 0, -1], self.prj])
 
+    @property
+    def is_rotated(self):
+        # type: () -> bool
+        """Return 'True' if the image has a rotation in the map info (i.e., is pseudo-projected)."""
+        return self.gt[2] != 0 or self.gt[4] != 0
+
     @property
     def nodata(self):
         """Get the nodata value of the GeoArray instance.
 
         If GeoArray has been instanced with a file path the metadata of the file on disk is checked for an existing
-        nodata value. Otherwise (if no value is exlicitly given during object instanciation) an automatic detection
+        nodata value. Otherwise, (if no value is exlicitly given during object instanciation) an automatic detection
         based on 3x3 windows at each image corner is run that analyzes the mean and standard deviation of these windows.
         """
         if self._nodata is not None:
@@ -495,6 +501,10 @@ class GeoArray(object):
             if False not in self.mask_nodata[:]:
                 # do not run raster2polygon if whole image is filled with data
                 self._footprint_poly = self.box.mapPoly
+            elif True not in self.mask_nodata[:]:
+                raise RuntimeError("Unable to compute a footprint polygon for %s '%s' "
+                                   "because the dataset only contains nodata values."
+                                   % (self.__class__.__name__, self.basename))
             else:
                 try:
                     multipolygon = raster2polygon(self.mask_nodata.astype(np.uint8), self.gt, self.prj, exact=False,
@@ -1051,6 +1061,7 @@ class GeoArray(object):
                 # write ds_src to disk and re-open it to add the metadata
                 gdal.Translate(out_path, ds_src, format=fmt, creationOptions=creationOptions)
                 del ds_src
+                # os.environ['GDAL_PAM_ENABLED'] = 'NO'
                 ds_out = gdal.Open(out_path, gdal.GA_Update)
 
                 for bidx in range(self.bands):
@@ -1177,7 +1188,7 @@ class GeoArray(object):
             image2plot = image2plot.astype(int)
 
         # rotated images always have to be resampled for plotting
-        if not ignore_rotation and (gt[2] or gt[4]):
+        if not ignore_rotation and self.is_rotated:
             out_prj = out_prj or self.projection
 
         if res_factor != 1. and image2plot.shape[0] * image2plot.shape[1] > 1e6:  # shape > 1000*1000
@@ -1598,12 +1609,12 @@ class GeoArray(object):
         self.arr, self.gt, self.projection = self.get_mapPos(mapBounds=poly.bounds)
         self.mask_nodata.arr, self.mask_nodata.gt, self.mask_nodata.projection = \
             self.mask_nodata.get_mapPos(mapBounds=poly.bounds, mapBounds_prj=self.prj)
-        assert self.shape == self.mask_nodata.shape
+        assert self.shape[:2] == self.mask_nodata.shape
 
         if self._mask_baddata is not None:
             self.mask_baddata.arr, self.mask_baddata.gt, self.mask_baddata.projection = \
                 self.mask_baddata.get_mapPos(mapBounds=poly.bounds)
-            assert self.shape == self.mask_baddata.shape
+            assert self.shape[:2] == self.mask_baddata.shape
 
         # update footprint polygon
         if self._footprint_poly:
@@ -1642,18 +1653,20 @@ class GeoArray(object):
 
         return GeneratorLen(out_gen, length=len(bounds_alltiles))
 
-    def get_mapPos(self, mapBounds, mapBounds_prj=None, band2get=None, out_prj=None, arr_gt=None, arr_prj=None,
-                   fillVal=None, rspAlg='near', progress=None, v=False):  # TODO implement slice for indexing bands
-        # type: (tuple, str, int, str, tuple, str, int, str, bool, bool) -> (np.ndarray, tuple, str)
+    def get_mapPos(self, mapBounds, mapBounds_prj=None, band2get=None, out_prj=None, out_gsd=None, arr_gt=None,
+                   arr_prj=None, fillVal=None, rspAlg='near', progress=None, v=False
+                   ):  # TODO implement slice for indexing bands
+        # type: (tuple, Union[str, int], int, Union[str, int], tuple, tuple, str, int, str, bool, bool) -> (np.ndarray, tuple, str)  # noqa
         """Return the array data of GeoArray at a given geographic position.
 
         NOTE: The given mapBounds are snapped to the pixel grid of GeoArray. If the given mapBounds include areas
         outside of the extent of GeoArray, these areas are filled with the fill value of GeoArray.
 
         :param mapBounds:       xmin, ymin, xmax, ymax
-        :param mapBounds_prj:   WKT projection string corresponding to mapBounds
+        :param mapBounds_prj:   WKT projection string or EPSG code corresponding to mapBounds
         :param band2get:        band index of the band to be returned (full array if not given)
-        :param out_prj:         output projection as WKT string. If not given, the self.projection is used.
+        :param out_prj:         output projection as WKT string or EPSG code. If not given, the self.projection is used.
+        :param out_gsd:         output spatial resolution in map units of the output projection (XGSD, YGSD)
         :param arr_gt:          GDAL GeoTransform (taken from self if not given)
         :param arr_prj:         WKT projection string (taken from self if not given)
         :param fillVal:         nodata value
@@ -1667,6 +1680,7 @@ class GeoArray(object):
         arr_gt = arr_gt or self.geotransform
         arr_prj = arr_prj or self.projection
         out_prj = out_prj or arr_prj
+        out_gsd = out_gsd or (self.xgsd, self.ygsd)
         fillVal = fillVal if fillVal is not None else self.nodata
         progress = progress if progress is not None else self.progress
 
@@ -1688,7 +1702,7 @@ class GeoArray(object):
                                                        mapBounds_prj=mapBounds_prj,
                                                        fillVal=fillVal,
                                                        rspAlg=rspAlg,
-                                                       out_gsd=(self.xgsd, self.ygsd),
+                                                       out_gsd=out_gsd,
                                                        band2get=band2get,
                                                        progress=progress)
         return sub_arr, sub_gt, sub_prj
