@@ -2,24 +2,26 @@
 
 # geoarray, A fast Python interface for image geodata - either on disk or in memory.
 #
-# Copyright (C) 2019  Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
+# Copyright (C) 2017-2023
+# - Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
+# - Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences Potsdam,
+#   Germany (https://www.gfz-potsdam.de/)
 #
 # This software was developed within the context of the GeoMultiSens project funded
 # by the German Federal Ministry of Education and Research
 # (project grant code: 01 IS 14 010 A-C).
 #
-# This program is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation, either version 3 of the License, or (at your option) any
-# later version.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
-# details.
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU Lesser General Public License along
-# with this program.  If not, see <http://www.gnu.org/licenses/>.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import warnings
 import numpy as np
@@ -226,9 +228,11 @@ def get_array_at_mapPos(arr, arr_gt, arr_prj, out_prj, mapBounds, mapBounds_prj=
         # mapBounds are expected to have the same projection like the input array
         if not prj_equal(arr_prj, mapBounds_prj):
             xmin, ymin, xmax, ymax = mapBounds
-            (xmin, ymin), (xmax, ymax) = \
-                [transform_any_prj(mapBounds_prj, arr_prj, X, Y) for X, Y in [(xmin, ymin), (xmax, ymax)]]
-            mapBounds = xmin, ymin, xmax, ymax
+            ULxy, URxy, LRxy, LLxy = \
+                [transform_any_prj(mapBounds_prj, arr_prj, X, Y)
+                 for X, Y in [(xmin, ymax), (xmax, ymax), (xmax, ymin), (xmin, ymin)]]
+            xvals, yvals = zip(ULxy, URxy, LRxy, LLxy)
+            mapBounds = min(xvals), min(yvals), max(xvals), max(yvals)
 
         out_prj = arr_prj
         out_arr, out_gt = _clip_array_at_mapPos(arr, mapBounds, arr_gt, band2clip=band2get, fillVal=fillVal)
@@ -239,7 +243,7 @@ def get_array_at_mapPos(arr, arr_gt, arr_prj, out_prj, mapBounds, mapBounds_prj=
         # calculate requested geo bounds in the target projection, snapped to the output array grid
         mapBounds = snap_bounds_to_pixGrid(mapBounds, arr_gt)
 
-        arr = arr[:, :, band2get] if band2get else arr[:]  # also converts GeoArray to numpy.ndarray
+        arr = arr[:, :, band2get] if band2get is not None else arr[:]  # also converts GeoArray to numpy.ndarray
 
         from py_tools_ds.geo.raster.reproject import warp_ndarray
         out_arr, out_gt, out_prj = \
